﻿using System;
using System.Windows.Input;
using Microsoft.Win32;
using WpfAudioPlayer.Commands;

namespace WpfAudioPlayer.ViewModels
{
	/// <summary>
	/// メイン ウィンドウの View と Model を仲介するクラスです。
	/// </summary>
	class MainWindowViewModel : ViewModelBase, IDisposable
	{
		/// <summary>
		/// インスタンスを初期化します。
		/// </summary>
		public MainWindowViewModel()
		{
			this.PlayerViewModel = new PlayerViewModel();
			this.PlayerViewModel.RequestNextSong += ( sender, e ) =>
			{
				var song = this.SongListViewModel.GetNextSong( e.IsNext, e.Song );
				if( song != null )
				{
					this.SongListViewModel.SelectedSong = song;
				}

				return song;
			};

			this.SongListViewModel = new SongListViewModel();
			this.SongListViewModel.SongSelecttionChanged += ( sender, e ) =>
			{
				this.PlayerViewModel.CurrentSong = e.Song;
			};

			this.InitializeCommand();
		}
		
		/// <summary>
		/// コマンドを初期化します。
		/// </summary>
		private void InitializeCommand()
		{
			// 再生
			this.ImportContentCommand = new DelegateCommand(
				() =>
				{
					var dialog = new OpenFileDialog() { Filter = "Audio Files (*.wav, *.mp3)|*.wav;*.mp3", Multiselect = true };
					var isOK   = dialog.ShowDialog();

					if( isOK.Value )
					{
						this.SongListViewModel.Add( dialog.FileNames );
					}
				}
				);
		}

		/// <summary>
		/// PlayerViewModel を取得します。
		/// </summary>
		public PlayerViewModel PlayerViewModel { get; private set; }

		/// <summary>
		/// SongListViewModel を取得します。
		/// </summary>
		public SongListViewModel SongListViewModel { get; private set; }

		/// <summary>
		/// 音楽ファイルを取り込みます。
		/// </summary>
		public ICommand ImportContentCommand { get; private set; }

		#region IDisposable メンバ

		/// <summary>
		/// リソースの解放を行います。
		/// </summary>
		public void Dispose()
		{
			if( this.PlayerViewModel != null )
			{
				this.PlayerViewModel.Dispose();
				this.PlayerViewModel = null;
			}

			if( this.SongListViewModel != null )
			{
				this.SongListViewModel = null;
			}
		}

		#endregion
	}
}
